import {Component, OnInit} from '@angular/core';
import {ScheduleInfo, ScheduleService} from "../../api";
import {NavigationLink} from "../navigation-link-list/navigation-link-list.component";
import {MatSnackBar} from "@angular/material/snack-bar";

@Component({
  selector: 'app-missed-schedules',
  templateUrl: './missed-schedules.component.html',
  styleUrls: ['./missed-schedules.component.css']
})
export class MissedSchedulesComponent implements OnInit{

  missedSchedules: ScheduleInfo[] = []
  defaultNavigationLinkPath: NavigationLink[] = [
    {
      linkText: "Dashboard",
      routerLink: ['/']
    },
    {
      linkText: "Missed Schedules",
      routerLink: ["/reschedule"]
    }
  ]
  constructor(private scheduleService: ScheduleService,
              private snackbar: MatSnackBar) {
  }

  ngOnInit() {
    this.scheduleService.schedulesMissedGet().subscribe({
      next: resp => {
        this.missedSchedules = resp;
      }
    })
  }

  forgetSchedule(scheduleInfo: ScheduleInfo) {
    this.scheduleService.schedulesScheduleIDScheduleTypeDelete(scheduleInfo.scheduleID, "BASIC").subscribe({
      next: resp => {
        this.missedSchedules = this.missedSchedules.filter(schedule => schedule.scheduleID !== scheduleInfo.scheduleID)
      },
      error: err => {
        if(err.status == 403) {
          this.snackbar.open("No permission", "", {duration: 2000})
        } else if(err.status == 404) {
          this.snackbar.open("Schedule not found", "", {duration: 2000});
        } else {
          this.snackbar.open("Unexpected error", "", {duration: 2000});
        }
      }
    })
  }
}
